@@ -24,10 +24,10 @@ fn bench_save_tower(bench: &mut Bencher) {
     let heaviest_bank = BankForks::new(Bank::default()).working_bank();
     let tower = Tower::new(
         &node_keypair.pubkey(),
-        &vote_account_pubkey,
+        vote_account_pubkey,
         0,
         &heaviest_bank,
-        &path,
+        path,
     );
 
     bench.iter(move || {
