@@ -13,6 +13,7 @@ use crate::{
     completed_data_sets_service::CompletedDataSetsSender,
     consensus::Tower,
     cost_update_service::CostUpdateService,
+    drop_bank_service::DropBankService,
     ledger_cleanup_service::LedgerCleanupService,
     replay_stage::{ReplayStage, ReplayStageConfig},
     retransmit_stage::RetransmitStage,
@@ -70,6 +71,7 @@ pub struct Tvu {
     accounts_hash_verifier: AccountsHashVerifier,
     voting_service: VotingService,
     cost_update_service: CostUpdateService,
+    drop_bank_service: DropBankService,
 }
 
 pub struct Sockets {
@@ -83,8 +85,8 @@ pub struct Sockets {
 pub struct TvuConfig {
     pub max_ledger_shreds: Option<u64>,
     pub shred_version: u16,
-    pub halt_on_trusted_validators_accounts_hash_mismatch: bool,
-    pub trusted_validators: Option<HashSet<Pubkey>>,
+    pub halt_on_known_validators_accounts_hash_mismatch: bool,
+    pub known_validators: Option<HashSet<Pubkey>>,
     pub repair_validators: Option<HashSet<Pubkey>>,
     pub accounts_hash_fault_injection_slots: u64,
     pub accounts_db_caching_enabled: bool,
@@ -217,8 +219,8 @@ impl Tvu {
             pending_snapshot_package,
             exit,
             cluster_info,
-            tvu_config.trusted_validators.clone(),
-            tvu_config.halt_on_trusted_validators_accounts_hash_mismatch,
+            tvu_config.known_validators.clone(),
+            tvu_config.halt_on_known_validators_accounts_hash_mismatch,
             tvu_config.accounts_hash_fault_injection_slots,
             snapshot_interval_slots,
         );
@@ -297,6 +299,9 @@ impl Tvu {
             cost_update_receiver,
         );
 
+        let (drop_bank_sender, drop_bank_receiver) = channel();
+        let drop_bank_service = DropBankService::new(drop_bank_receiver);
+
         let replay_stage = ReplayStage::new(
             replay_stage_config,
             blockstore.clone(),
@@ -316,6 +321,7 @@ impl Tvu {
             cluster_slots_update_sender,
             voting_sender,
             cost_update_sender,
+            drop_bank_sender,
         );
 
         let ledger_cleanup_service = tvu_config.max_ledger_shreds.map(|max_ledger_shreds| {
@@ -348,6 +354,7 @@ impl Tvu {
             accounts_hash_verifier,
             voting_service,
             cost_update_service,
+            drop_bank_service,
         }
     }
 
@@ -363,6 +370,7 @@ impl Tvu {
         self.accounts_hash_verifier.join()?;
         self.voting_service.join()?;
         self.cost_update_service.join()?;
+        self.drop_bank_service.join()?;
         Ok(())
     }
 }
